API
===

Public API of `spyrrow`

.. autoclass:: spyrrow::Item

.. autoclass:: spyrrow::StripPackingInstance
    :members: solve, to_json_str

.. autoclass:: spyrrow::StripPackingConfig

.. autoclass:: spyrrow::StripPackingSolution

.. autoclass:: spyrrow::PlacedItem